/* This test driver program encodes a data record and writes the        */
/* encoded result to an output file..                                   */

#include <stdio.h>
#include <stdlib.h>
#include "test.h"

int main (int argc, char** argv)
{
   ShirtType    shirtType;
   OSCTXT	ctxt;
   int		i, stat;
   const char*  filename = "message.xml";
   OSBOOL       trace = TRUE;

   /* Process command line arguments */

   if (argc > 1) {
      for (i = 1; i < argc; i++) {
         if (!strcmp (argv[i], "-v")) /* rtSetDiag (1) */ ;
         else if (!strcmp (argv[i], "-o")) filename = argv[++i];
         else if (!strcmp (argv[i], "-notrace")) trace = FALSE;
         else {
            printf ("usage: writer [ -v ] [ -o <filename>\n");
            printf ("   -v  verbose mode: print trace info\n");
            printf ("   -o <filename>  write encoded msg to <filename>\n");
            printf ("   -notrace  do not display trace info\n");
            return 0;
         }
      }
   }

   /* Init context */

   stat = rtXmlInitContext (&ctxt);
   if (0 != stat) {
      printf ("Context initialization failed.\n");
      rtxErrPrint (&ctxt);
      return stat;
   }

   /* Populate structure of generated type */

   Init_ShirtType (&ctxt, &shirtType);

   shirtType._base.number = 28563;
   shirtType._base.name.value = (const OSUTF8CHAR*)"myShirtType";

   { ShirtType_2* pdata0;
   OSRTDList* plist = &shirtType._ext;
   pdata0 = rtxMemAllocType (&ctxt, ShirtType_2);
   Init_ShirtType_2 (&ctxt, pdata0);
   pdata0->t = T_ShirtType_2_color;
   pdata0->u.color = ColorType_red;
   rtxDListAppend (&ctxt, plist, pdata0);

   pdata0 = rtxMemAllocType (&ctxt, ShirtType_2);
   Init_ShirtType_2 (&ctxt, pdata0);
   pdata0->t = T_ShirtType_2_size;
   pdata0->u.size = 7;
   rtxDListAppend (&ctxt, plist, pdata0);
   }

   /* Encode */

   stat = rtXmlSetEncBufPtr (&ctxt, 0, 0);

   if (0 == stat)
      stat = XmlE_myProduct (&ctxt, &shirtType);

   if (0 == stat) {
      if (trace) {
         printf ("encoded XML message:\n");
         puts ((char*)rtXmlGetEncBufPtr(&ctxt));
         printf ("\n");
      }
   }
   else {
      printf ("Encoding failed\n");
      rtxErrPrint (&ctxt);
      return stat;
   }
  
   /* Write the encoded message out to the output file */

  stat = rtXmlWriteToFile (&ctxt, filename);
  if (0 != stat) {
     printf ("Write to file %s failed\n", filename);
     rtxErrPrint (&ctxt);
  } 

   rtxFreeContext (&ctxt);
   return 0;
}
