#include <stdio.h>
#include <stdlib.h>
#include "rtxmlsrc/rtXmlCppMsgBuf.h"
#include "cap.h"

static void Test_alert (alert_ELEM* pvalue)
{
   pvalue->identifier.setValue ("43b080713727");

   pvalue->sender.setValue ("hsas@dhs.gov");

   pvalue->sent.setValue ("2003-04-02T14:39:01-05:00");

   pvalue->status = alert_ELEM_status::Actual;

   pvalue->msgType = alert_ELEM_msgType::Alert;

   pvalue->m.scopePresent = 1;
   pvalue->scope = alert_ELEM_scope::Public;

   { alert_ELEM_info* pdata1;
   pdata1 = new alert_ELEM_info();

   { alert_ELEM_info_category* pdata2;
   pdata2 = new alert_ELEM_info_category();
   *pdata2 = alert_ELEM_info_category::Security;
   pdata1->category.append (pdata2);
   }

   pdata1->event.setValue ("Homeland Security Advisory System Update");

   pdata1->urgency = alert_ELEM_info_urgency::Immediate;

   pdata1->severity = alert_ELEM_info_severity::Severe;

   pdata1->certainty = alert_ELEM_info_certainty::Likely;

   pdata1->m.senderNamePresent = 1;
   pdata1->senderName.setValue 
      ("U.S. Government, Department of Homeland Security");

   pdata1->m.headlinePresent = 1;
   pdata1->headline.setValue ("Homeland Security Sets Code ORANGE");

   pdata1->m.descriptionPresent = 1;
   pdata1->description.setValue ("The Department of Homeland Security has elevated the Homeland Security Advisory System threat level to ORANGE / High in response to intelligence which may indicate a heightened threat of terrorism.");

   pdata1->m.instructionPresent = 1;
   pdata1->instruction.setValue (" A High Condition is declared when there is a high risk of terrorist attacks. In addition to the Protective Measures taken in the previous Threat Conditions, Federal departments and agencies should consider agency specific Protective Measures in accordance with their existing plans.");

   pdata1->m.webPresent = 1;
   pdata1->web.setValue ("http://www.dhs.gov/dhspublic/display?theme=29");

   { OSXMLStringClass* pdata3;
   pdata3 = new OSXMLStringClass();
   pdata3->setValue ("HSAS=ORANGE");
   pdata1->parameter.append (pdata3);
   }

   { alert_ELEM_info_resource* pdata3;
   pdata3 = new alert_ELEM_info_resource();
   pdata3->resourceDesc.setValue ("Image file (GIF)");

   pdata3->m.uriPresent = 1;
   pdata3->uri.setValue ("http://www.dhs.gov/dhspublic/getAdvisoryImage");

   pdata1->resource.append (pdata3);
   }

   { alert_ELEM_info_area* pdata3;
   pdata3 = new alert_ELEM_info_area();
   pdata3->areaDesc.setValue ("U.S. nationwide and interests worldwide");

   pdata1->area.append (pdata3);
   }

   pvalue->info.append (pdata1);
   }
}

int main (int argc, char** argv)
{
   int          i, stat;
   const char*  filename = "message.xml";
   OSBOOL       trace = TRUE, verbose = FALSE;
   const OSOCTET* msgptr;

   // Process command line arguments

   if (argc > 1) {
      for (i = 1; i < argc; i++) {
         if (!strcmp (argv[i], "-v")) verbose = TRUE;
         else if (!strcmp (argv[i], "-o")) filename = argv[++i];
         else if (!strcmp (argv[i], "-notrace")) trace = FALSE;
         else {
            printf ("usage: writer [-v] [-o <filename>] [-notrace]\n");
            printf ("   -v  verbose mode: print trace info\n");
            printf ("   -o <filename>  write encoded msg to <filename>\n");
            printf ("   -notrace  do not display trace info\n");
            return 0;
         }
      }
   }

   // Create buffer and control objects

   alert_ELEM msgdata;
   OSXMLEncodeBuffer buffer;
   alert_CC pdu (buffer, msgdata);

   buffer.setDiag (verbose);

   // Populate structure of generated type

   Test_alert (&msgdata);

   // Encode

   stat = pdu.encode();

   if (0 == stat) {
      if (trace) {
         msgptr = buffer.getMsgPtr();
         printf ("encoded XML message:\n");
         printf ("%s\n", (const char*)msgptr);
      }

      // Write the encoded message out to the output file

      if (buffer.write (filename) <= 0) {
         printf ("Can't write to %s\n", filename);
         return -1;
      }
   }
   else {
      printf ("Encoding failed\n");
      buffer.printErrorInfo();
      return stat;
   }

   return 0;
}
