/* This test driver program reads an encoded record from a file         */
/* and decodes it and displays the results..                            */

#include <stdio.h>
#include <stdlib.h>
#include "rtxsrc/OSRTFileInputStream.h"
#include "rtxmlsrc/rtXmlCppMsgBuf.h"
#include "make-call.h"

int main (int argc, char** argv)
{
   int		i, stat;
   const char*  filename = "message.xml";
   OSBOOL       trace = TRUE, verbose = FALSE;

   /* Process command line arguments */

   if (argc > 1) {
      for (i = 1; i < argc; i++) {
         if (!strcmp (argv[i], "-v")) verbose = TRUE;
         else if (!strcmp (argv[i], "-i")) filename = argv[++i];
         else if (!strcmp (argv[i], "-notrace")) trace = FALSE;
         else {
            printf ("usage: reader [ -v ] [ -i <filename>] [ -notrace ]\n");
            printf ("   -v  verbose mode: print trace info\n");
            printf ("   -i <filename>  read encoded msg from <filename>\n");
            printf ("   -notrace  do not display trace info\n");
            return 0;
         }
      }
   }

   OSRTFileInputStream in (filename);
   OSXMLDecodeBuffer decodeBuffer (in);

   if (decodeBuffer.getStatus ()) {
      decodeBuffer.printErrorInfo();
      return decodeBuffer.getStatus ();
   }

   MakeCall_ELEM value;
   MakeCall_CC pdu (decodeBuffer, value);

   decodeBuffer.setDiag (verbose);

   // Decode

   stat = pdu.decode();

   if (0 == stat) {
      if (trace) {
         printf ("decoded XML message:\n");
         pdu.print ("make-call");
         printf ("\n");
      }
   }
   else {
      printf ("Decoding failed\n");
      decodeBuffer.printErrorInfo();
      return stat;
   }

   return 0;
}

