/* This test driver program encodes a data record and writes the        */
/* encoded result to an output file..                                   */

#include <stdio.h>
#include <stdlib.h>
#include "rtxmlsrc/rtXmlCppMsgBuf.h"
#include "rtxsrc/rtxMemLeakCheck.h"
#include "employee.h"

DECLARE_MEMLEAK_DETECTOR;

static void fill_jSmith (PersonnelRecord* pPR);

int main (int argc, char** argv)
{
   int		i, stat;
   const char*  filename = "message.xml";
   OSBOOL       trace = TRUE, verbose = FALSE;
   const OSOCTET* msgptr;

   // Process command line arguments

   if (argc > 1) {
      for (i = 1; i < argc; i++) {
         if (!strcmp (argv[i], "-v")) verbose = TRUE;
         else if (!strcmp (argv[i], "-o")) filename = argv[++i];
         else if (!strcmp (argv[i], "-notrace")) trace = FALSE;
         else {
            printf ("usage: writer [ -v ] [ -o <filename>\n");
            printf ("   -v  verbose mode: print trace info\n");
            printf ("   -o <filename>  write encoded msg to <filename>\n");
            printf ("   -notrace  do not display trace info\n");
            return 0;
         }
      }
   }

   // Create buffer and control objects

   PersonnelRecord value;
   OSXMLEncodeBuffer buffer;
   personnelRecord_CC pdu (buffer, value);

   if (verbose) 
      rtxSetDiag (pdu.getCtxtPtr(), 1);

   if (trace) 
      printf ("sizeof(PersonnelRecord) = %zu\n", sizeof(PersonnelRecord));

   // Populate structure of generated type

   fill_jSmith (&value);

   // Encode

   stat = pdu.encode();

   if (0 == stat) {
      if (trace) {
         msgptr = buffer.getMsgPtr();
         printf ("encoded XML message:\n");
         printf ("%s\n", (const char*)msgptr);
      }
   }
   else {
      printf ("Encoding failed\n");
      buffer.printErrorInfo();
      return stat;
   }

   // Write the encoded message out to the output file

   if (buffer.write (filename) <= 0) {
      printf ("Can't write to %s\n", filename);
      return -1;
   }

   return 0;
}

// Routine to fill the employee record with test data


static void fill_jSmith (PersonnelRecord* pPR)
{
   ChildInformation* pChildInfo;


   pPR->title.setValue ("Director");
   pPR->number.value = 51;
   pPR->dateOfHire.setValue ((const OSUTF8CHAR*)"19710917");


   // fill first child record

   pChildInfo = new ChildInformation();
   pChildInfo->dateOfBirth.setValue ((const OSUTF8CHAR*)"19571111");
   pPR->children.append (pChildInfo);

   // fill second child record

   pChildInfo = new ChildInformation();
   pChildInfo->dateOfBirth.setValue ((const OSUTF8CHAR*)"19590717");
   pPR->children.append (pChildInfo);
}

