import com.test.*;
import javax.xml.datatype.DatatypeConstants;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.ByteArrayOutputStream;
import java.io.BufferedInputStream;
import java.io.FileOutputStream;
import java.util.List;
import com.objsys.xbinder.runtime.*;

/**
 * This test program encodes a data record and writes the encoded result to an output file.
 */
public class Writer {

   private static DatatypeFactory dtFactory;

   static {
      try {
         dtFactory = DatatypeFactory.newInstance();
      }
      catch ( javax.xml.datatype.DatatypeConfigurationException dce ) 
      { throw new RuntimeException(dce); }
   }

   private static String outputFile = "message.xml";
   private static String charset = "UTF-8";     //default is UTF-8
   private static boolean trace = true;

   public static void main(String args[]) throws Exception
   {
      //process command line to get the name of the output file
      //process command line to get the name of the input file
      for(int arg = 0; arg < args.length; arg++) {
         if ( args[arg].equals("-o")) {
           outputFile = args[++arg];
         }
         else if ( args[arg].equals("-notrace" ) ) trace = false;
         else {
            System.out.println("Usage: java Writer [-o <filename>] [-notrace]");
            System.out.println("  -o <filename> specifies the output file");
            System.out.println("  -notrace turns off echoing encoded data to stdout");
            System.exit(1);
         }
      }

      //create _CC object
      Items_CC root = new Items_CC();

      ItemsType items = new ItemsType();
      root.setItems(items);

      java.util.List<com.test.ItemsType_0> itemsType_0;
      itemsType_0 = items.getItemsType_0();

      ItemsType_0 itemsType_0N;
      ProductType hat;
      RestrictedProductType umbrella;
      ShirtType shirt;
      XMLGregorianCalendar effDate;

      itemsType_0N = new ItemsType_0();
      itemsType_0.add(itemsType_0N);
      hat = new ProductType();
      itemsType_0N.setHat(hat);
      hat.setRoutingNum(123456);
      effDate = dtFactory.newXMLGregorianCalendarDate(2002, 4, 2, DatatypeConstants.FIELD_UNDEFINED);
      hat.setEffDate(effDate);
      hat.setLang("en-US");
      hat.setNumber(557);
      hat.setName("Ten-Gallon Hat");
      hat.setDescription("This is a great hat!");

      itemsType_0N = new ItemsType_0();
      itemsType_0.add(itemsType_0N);
      umbrella = new RestrictedProductType();
      itemsType_0N.setUmbrella(umbrella);
      umbrella.setRoutingNum(123);
      effDate = dtFactory.newXMLGregorianCalendarDate(2002, 4, 2, DatatypeConstants.FIELD_UNDEFINED);
      umbrella.setEffDate(effDate);
      umbrella.setNumber(557);
      umbrella.setName("Ten-Gallon Hat");


      java.util.List<ShirtType_2> shirtType_2;
      ShirtType_2 shirtType_2N;
      ColorType color;
      SmallSizeType size;

      itemsType_0N = new ItemsType_0();
      itemsType_0.add(itemsType_0N);
      shirt = new ShirtType();
      itemsType_0N.setShirt(shirt);
      shirt.setRoutingNum(124);
      effDate = dtFactory.newXMLGregorianCalendarDate(2002, 4, 2, DatatypeConstants.FIELD_UNDEFINED);
      shirt.setEffDate(effDate);
      shirt.setNumber(557);
      shirt.setName("Short-Sleeved Linen Blouse");
      shirt.setSleeve(17);

      shirtType_2 = shirt.getShirtType_2();

      shirtType_2N = new ShirtType_2();
      shirtType_2.add(shirtType_2N);
      color = new ColorType();
      shirtType_2N.setColor(color);
      color.setValue("blue");

      shirtType_2N = new ShirtType_2();
      shirtType_2.add(shirtType_2N);
      size = new SmallSizeType();
      shirtType_2N.setSize(size);
      size.setValue(6);
      size.setSystem_("US-DRESS");


      //Encode data
      ByteArrayOutputStream bos = new ByteArrayOutputStream(32768);

      XBXmlEncoder encoder;
      encoder = new XBXmlEncoder(bos, charset);
      encoder.setNamespaces(_test.namespaceContext);
      root.encodeDocument(encoder);
      encoder.close();

      if ( trace ) {
         //write encoded data to System.out
         System.out.println("Encoded data:\n");
         bos.writeTo(System.out);
         System.out.println();
      }

      //write encoded data to output file
      FileOutputStream fout = new FileOutputStream(outputFile);
      bos.writeTo(fout);
      fout.close();
   }
}
