import javax.xml.datatype.DatatypeConstants;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.io.ByteArrayOutputStream;
import java.io.BufferedInputStream;
import java.io.FileOutputStream;
import java.util.List;
import com.objsys.xbinder.runtime.*;

/**
 * This test program encodes a data record and writes the encoded result to an output file.
 */
public class Writer {

   private static DatatypeFactory dtFactory;

   static {
      try {
         dtFactory = DatatypeFactory.newInstance();
      }
      catch ( javax.xml.datatype.DatatypeConfigurationException dce ) 
      { throw new RuntimeException(dce); }
   }

   private static String outputFile = "message.xml";
   private static String charset = "UTF-8";     //default is UTF-8
   private static boolean trace = true;

   public static void main(String args[]) throws Exception 
   {
      //process command line to get the name of the output file
      //process command line to get the name of the input file
      for(int arg = 0; arg < args.length; arg++) {
         if ( args[arg].equals("-o")) {
           outputFile = args[++arg];
         }
         else if ( args[arg].equals("-notrace" ) ) trace = false;
         else {
            System.out.println("Usage: java Writer [-o <filename>] [-notrace]");
            System.out.println("  -o <filename> specifies the output file");
            System.out.println("  -notrace turns off echoing encoded data to stdout");
            System.exit(1);
         }
      }

      //create _CC object
      com.test.client.Message_CC root = new com.test.client.Message_CC();
      com.test.client.Message_ELEM message = new com.test.client.Message_ELEM();
      root.setMessage(message);
      message.addNamespace("jabber:client", "");

      message.setFrom("juliet@example.com");
      message.setTo("romeo@example.com");
      message.setLang("en");

      java.util.List<com.test.client.Message_ELEM_1> message_ELEM_1;
      message_ELEM_1 = message.getMessage_ELEM_1();

      com.test.client.Message_ELEM_1 message_ELEM_1N = new com.test.client.Message_ELEM_1();
      message_ELEM_1.add( message_ELEM_1N );

      com.test.client.Body_ELEM body;

      body = new com.test.client.Body_ELEM();
      message_ELEM_1N.setBody(body);

      body.setValue( "Art thou not Romeo, and a Montague?" );


      //Encode data
      ByteArrayOutputStream bos = new ByteArrayOutputStream(32768);

      XBXmlEncoder encoder;
      encoder = new XBXmlEncoder(bos, charset);
      root.encodeDocument(encoder);
      encoder.close();

      if ( trace ) {
         //write encoded data to System.out
         System.out.println("Encoded data:\n");
         bos.writeTo(System.out);
         System.out.println();
      }

      //write encoded data to output file
      FileOutputStream fout = new FileOutputStream(outputFile);
      bos.writeTo(fout);
      fout.close();
   }
}
